@@ -1,75 +1,64 @@
-package RDF::NS::Curated;
-
-use 5.006000;
+use 5.010001;
 use strict;
 use warnings;
 
+package RDF::NS::Curated;
+
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.900_01';
+our $VERSION   = '0.001';
 
 sub new {
   my $class = shift;
   my %prefix_ns = (
-						 adms => 'http://www.w3.org/ns/adms#',
-						 as => 'https://www.w3.org/ns/activitystreams#',
-						 bibo => 'http://purl.org/ontology/bibo/',
+						 rdfs => 'http://www.w3.org/2000/01/rdf-schema#',
+						 vcard => 'http://www.w3.org/2006/vcard/ns#',
+						 ical => 'http://www.w3.org/2002/12/cal/icaltzd#',
+						 rdfa => 'http://www.w3.org/ns/rdfa#',
+						 grddl => 'http://www.w3.org/2003/g/data-view#',
+						 qb => 'http://purl.org/linked-data/cube#',
+						 wdrs => 'http://www.w3.org/2007/05/powder-s#',
 						 cc => 'http://creativecommons.org/ns#',
-						 csvw => 'http://www.w3.org/ns/csvw#',
+						 dc11 => 'http://purl.org/dc/elements/1.1/ => ',
+						 rdf => 'http://www.w3.org/1999/02/22-rdf-syntax-ns#',
+						 xml => 'http://www.w3.org/XML/1998/namespace',
+						 gr => 'http://purl.org/goodrelations/v1#',
+						 og => 'http://ogp.me/ns#',
+						 rr => 'http://www.w3.org/ns/r2rml#',
+						 ma => 'http://www.w3.org/ns/ma-ont#',
+						 v => 'http://rdf.data-vocabulary.org/#',
+						 owl => 'http://www.w3.org/2002/07/owl#',
+						 foaf => 'http://xmlns.com/foaf/0.1/',
+						 rif => 'http://www.w3.org/2007/rif#',
+						 sd => 'http://www.w3.org/ns/sparql-service-description#',
+						 schema => 'http://schema.org/',
+						 org => 'http://www.w3.org/ns/org#',
+						 skosxl => 'http://www.w3.org/2008/05/skos-xl#',
+						 xsd => 'http://www.w3.org/2001/XMLSchema#',
+						 dc => 'http://purl.org/dc/terms/',
+						 sioc => 'http://rdfs.org/sioc/ns#',
+						 prov => 'http://www.w3.org/ns/prov#',
+						 skos => 'http://www.w3.org/2004/02/skos/core#',
+						 dcat => 'http://www.w3.org/ns/dcat#',
+						 rev => 'http://purl.org/stuff/rev#',
+						 wdr => 'http://www.w3.org/2007/05/powder#',
+						 void => 'http://rdfs.org/ns/void#',
 						 ctag => 'http://commontag.org/ns#',
+						 xhv => 'http://www.w3.org/1999/xhtml/vocab#',
+						 yago => 'http://yago-knowledge.org/resource/',
 						 dbo => 'http://dbpedia.org/ontology/',
 						 dbp => 'http://dbpedia.org/property/',
-						 dc => 'http://purl.org/dc/terms/',
-						 dc11 => 'http://purl.org/dc/elements/1.1/',
-						 dcat => 'http://www.w3.org/ns/dcat#',
-						 dctype => 'http://purl.org/dc/dcmitype/',
-						 doap => 'http://usefulinc.com/ns/doap#',
-						 dqv => 'http://www.w3.org/ns/dqv#',
-						 duv => 'http://www.w3.org/ns/duv#',
-						 earl => 'http://www.w3.org/ns/earl#',
-						 event => 'http://purl.org/NET/c4dm/event.owl#',
-						 foaf => 'http://xmlns.com/foaf/0.1/',
-						 frbr => 'http://purl.org/vocab/frbr/core#',
-						 gn => 'http://www.geonames.org/ontology#',
-						 gr => 'http://purl.org/goodrelations/v1#',
-						 grddl => 'http://www.w3.org/2003/g/data-view#',
-						 hydra => 'http://www.w3.org/ns/hydra/core#',
-						 ical => 'http://www.w3.org/2002/12/cal/icaltzd#',
-						 ldp => 'http://www.w3.org/ns/ldp#',
-						 ma => 'http://www.w3.org/ns/ma-ont#',
-						 oa => 'http://www.w3.org/ns/oa#',
-						 odrl => 'http://www.w3.org/ns/odrl/2/',
-						 og => 'http://ogp.me/ns#',
-						 org => 'http://www.w3.org/ns/org#',
-						 owl => 'http://www.w3.org/2002/07/owl#',
-						 pos => 'http://www.w3.org/2003/01/geo/wgs84_pos#',
-						 prov => 'http://www.w3.org/ns/prov#',
-						 qb => 'http://purl.org/linked-data/cube#',
-						 rel => 'http://purl.org/vocab/relationship/',
-						 rev => 'http://purl.org/stuff/rev#',
-						 rif => 'http://www.w3.org/2007/rif#',
-						 rdf => 'http://www.w3.org/1999/02/22-rdf-syntax-ns#',
-						 rdfa => 'http://www.w3.org/ns/rdfa#',
-						 rdfs => 'http://www.w3.org/2000/01/rdf-schema#',
-						 rr => 'http://www.w3.org/ns/r2rml#',
-						 schema => 'http://schema.org/',
-						 sd => 'http://www.w3.org/ns/sparql-service-description#',
-						 sioc => 'http://rdfs.org/sioc/ns#',
-						 skos => 'http://www.w3.org/2004/02/skos/core#',
-						 skosxl => 'http://www.w3.org/2008/05/skos-xl#',
-						 sosa => 'http://www.w3.org/ns/sosa/',
-						 ssn => 'http://www.w3.org/ns/ssn/',
-						 time => 'http://www.w3.org/2006/time#',
-						 v => 'http://rdf.data-vocabulary.org/#',
 						 vann => 'http://purl.org/vocab/vann/',
-						 vcard => 'http://www.w3.org/2006/vcard/ns#',
-						 void => 'http://rdfs.org/ns/void#',
+						 pos => 'http://www.w3.org/2003/01/geo/wgs84_pos#',
+						 time => 'http://www.w3.org/2006/time#',
+						 bibo => 'http://purl.org/ontology/bibo/',
 						 vs => 'http://www.w3.org/2003/06/sw-vocab-status/ns#',
-						 wdr => 'http://www.w3.org/2007/05/powder#',
-						 wdrs => 'http://www.w3.org/2007/05/powder-s#',
-						 xhv => 'http://www.w3.org/1999/xhtml/vocab#',
-						 xml => 'http://www.w3.org/XML/1998/namespace',
-						 xsd => 'http://www.w3.org/2001/XMLSchema#',
-						 yago => 'http://yago-knowledge.org/resource/',
+						 doap => 'http://usefulinc.com/ns/doap#',
+						 dctype => 'http://purl.org/dc/dcmitype/',
+						 gn => 'http://www.geonames.org/ontology#',
+						 frbr => 'http://purl.org/vocab/frbr/core#',
+						 adms => 'http://www.w3.org/ns/adms#',
+						 event => 'http://purl.org/NET/c4dm/event.owl#',
+						 rel => 'http://purl.org/vocab/relationship/'
 						);
 
   my $self = {
@@ -95,35 +84,6 @@ sub prefix {
   return $ns_prefix->{$namespace};
 }
 
-sub qname {
-  my $self = shift;
-  my $uri = shift;
-
-  # regexpes copied from RDF::Trine::Node::Resource
-  our $r_PN_CHARS_BASE ||= qr/([A-Z]|[a-z]|[\x{00C0}-\x{00D6}]|[\x{00D8}-\x{00F6}]|[\x{00F8}-\x{02FF}]|[\x{0370}-\x{037D}]|[\x{037F}-\x{1FFF}]|[\x{200C}-\x{200D}]|[\x{2070}-\x{218F}]|[\x{2C00}-\x{2FEF}]|[\x{3001}-\x{D7FF}]|[\x{F900}-\x{FDCF}]|[\x{FDF0}-\x{FFFD}]|[\x{10000}-\x{EFFFF}])/;
-  our $r_PN_CHARS_U    ||= qr/(_|${r_PN_CHARS_BASE})/;
-  our $r_PN_CHARS      ||= qr/${r_PN_CHARS_U}|-|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]/;
-  our $r_PN_LOCAL      ||= qr/((${r_PN_CHARS_U})((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/;
-
-  my $ln;
-  my $pr;
-  while (my ($prefix, $namespace) = each(%{$self->{prefix_namespace}})) {
-	  if($uri =~ m/^$namespace(${r_PN_LOCAL})$/) {
-		  $ln = $1;
-		  $pr = $prefix;
-		  my $n = scalar keys (%{$self->{prefix_namespace}}); # reset iterator
-		  last;
-	  }
-  }
-  return unless defined($ln);
-  return wantarray ? ($pr, $ln) : "$pr:$ln";
-}
-
-sub all {
-  my $self = shift;
-  return $self->{prefix_namespace};
-}
-
 1;
 
 __END__
@@ -144,43 +104,24 @@ RDF::NS::Curated - A curated set of RDF prefixes
 
 =head1 DESCRIPTION
 
-This contains a list of 60 prefix and URI pairs that are commonly used
+This contains a list of 49 prefix and URI pairs that are commonly used
 in RDF. The intention is that prefixes in this list can be safely used
 in code that has a long lifetime. The list has been derived mostly
-from W3C standards documents, but also some popularity lists. See the
-source code of this package for the full list.
+from W3C standards documents, but also some popularity lists.
 
 It is intended to be used with e.g. L<URI::NamespaceMap>.
 
-=head2 Methods
+Apart from the constructor, which takes no arguments, it has only two methods:
 
 =over
 
-=item C<< new >>
-
-Constructor. Takes no arguments.
-
 =item C<< uri($prefix) >>
 
-This will return the URI (as a plain string) of the supplied prefix or C<undef> if it is not registered.
+This will return the URI (as a plain string) of the supplied prefix.
 
 =item C<< prefix($uri) >>
 
-This will return the prefix corresponding to the supplied URI string or C<undef> if it is not registered.
-
-=item C<< qname($uri) >>
-
-This will return the qualified name corresponding to the supplied URI
-string or C<undef> if it is not registered. In scalar context, it will
-return the prefix and local name with a colon, and list context, a
-two-element array containing prefix and local name.
-
-For example C<http://purl.org/dc/terms/name> will return C<dc:name> in
-scalar context and C<('dc', 'name')> in list context.
-
-=item C<< all >>
-
-This will return a hashref with all prefix and URI pairs.
+This will return the prefix corresponding to the supplied URI string.
 
 =back
 
@@ -197,14 +138,9 @@ L<RDF::NS>, L<XML::CommonNS>, L<RDF::Prefixes>.
 
 Kjetil Kjernsmo E<lt>kjetilk@cpan.orgE<gt>.
 
-=head1 CONTRIBUTORS
-
-Harald Jörg
-
-
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2015, 2017, 2018 by Kjetil Kjernsmo.
+This software is copyright (c) 2015 by Kjetil Kjernsmo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
